==> haskell-deepseq-generics-0.2.0.0-22-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-deepseq-generics.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 deepseq-generics
version:              0.2.0.0
visibility:           public
id:                   deepseq-generics-0.2.0.0-KHSZaZ6oQt6B2GMZXpGW7o
key:                  deepseq-generics-0.2.0.0-KHSZaZ6oQt6B2GMZXpGW7o
license:              BSD-3-Clause
copyright:            2012, Herbert Valerio Riedel
maintainer:           hvr@gnu.org
author:               Herbert Valerio Riedel
homepage:             https://github.com/hvr/deepseq-generics
synopsis:             GHC.Generics-based Control.DeepSeq.rnf implementation
description:
    This package provides a "GHC.Generics"-based
    '\''Control.DeepSeq.Generics.genericRnf'\'' function which can be used
    for providing a '\''rnf'\'' implementation. See the documentation for
    the '\''genericRnf'\'' function in the "Control.DeepSeq.Generics" module
    to get started.

    The original idea was pioneered in the @generic-deepseq@ package
    (see <http://www.haskell.org/pipermail/haskell-cafe/2012-February/099551.html>
    for more information).

    This package differs from the @generic-deepseq@ package by working
    in combination with the existing @deepseq@ package as opposed to
    defining a conflicting drop-in replacement for @deepseq@'\''s
    @Control.DeepSeq@ module.

    __Note__: The ability to auto-derive via "GHC.Generics" has been
    merged into @deepseq-1.4.0.0@. This package is now still useful
    for writing code that'\''s also compatible with older @deepseq@
    versions not yet providing "GHC.Generics"-support.

category:             Control
abi:                  c1e9614344333b44e79b23d442d7bc31
exposed:              True
exposed-modules:      Control.DeepSeq.Generics
import-dirs:          /usr/lib/ghc-9.0.1/site-local/deepseq-generics-0.2.0.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/deepseq-generics-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/deepseq-generics-0.2.0.0
hs-libraries:         HSdeepseq-generics-0.2.0.0-KHSZaZ6oQt6B2GMZXpGW7o
depends:              base-4.15.0.0 deepseq-1.4.5.0 ghc-prim-0.7.0
haddock-interfaces:
    /usr/share/doc/haskell-deepseq-generics/html/deepseq-generics.haddock

haddock-html:         /usr/share/doc/haskell-deepseq-generics/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-deepseq-generics-0.2.0.0-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-deepseq-generics.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 deepseq-generics
version:              0.2.0.0
visibility:           public
id:                   deepseq-generics-0.2.0.0-9682ZVURzNbHZYQhqPOLhU
key:                  deepseq-generics-0.2.0.0-9682ZVURzNbHZYQhqPOLhU
license:              BSD-3-Clause
copyright:            2012, Herbert Valerio Riedel
maintainer:           hvr@gnu.org
author:               Herbert Valerio Riedel
homepage:             https://github.com/hvr/deepseq-generics
synopsis:             GHC.Generics-based Control.DeepSeq.rnf implementation
description:
    This package provides a "GHC.Generics"-based
    '\''Control.DeepSeq.Generics.genericRnf'\'' function which can be used
    for providing a '\''rnf'\'' implementation. See the documentation for
    the '\''genericRnf'\'' function in the "Control.DeepSeq.Generics" module
    to get started.

    The original idea was pioneered in the @generic-deepseq@ package
    (see <http://www.haskell.org/pipermail/haskell-cafe/2012-February/099551.html>
    for more information).

    This package differs from the @generic-deepseq@ package by working
    in combination with the existing @deepseq@ package as opposed to
    defining a conflicting drop-in replacement for @deepseq@'\''s
    @Control.DeepSeq@ module.

    __Note__: The ability to auto-derive via "GHC.Generics" has been
    merged into @deepseq-1.4.0.0@. This package is now still useful
    for writing code that'\''s also compatible with older @deepseq@
    versions not yet providing "GHC.Generics"-support.

category:             Control
abi:                  a17638bfff1707282900fb36e04fb379
exposed:              True
exposed-modules:      Control.DeepSeq.Generics
import-dirs:          /usr/lib/ghc-9.0.2/site-local/deepseq-generics-0.2.0.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/deepseq-generics-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/deepseq-generics-0.2.0.0
hs-libraries:         HSdeepseq-generics-0.2.0.0-9682ZVURzNbHZYQhqPOLhU
depends:              base-4.15.1.0 deepseq-1.4.5.0 ghc-prim-0.7.0
haddock-interfaces:
    /usr/share/doc/haskell-deepseq-generics/html/deepseq-generics.haddock

haddock-html:         /usr/share/doc/haskell-deepseq-generics/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
